<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/svp?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'action_patienter' => 'Li acioun soun en cours de tratamen. Vourguès passientà…',
	'actions_a_faire' => 'Acioun a tratà',
	'actions_demandees' => 'Acioun demandadi :',
	'actions_en_erreur' => 'Errour sourvengudi',
	'actions_necessaires' => 'Li acioun suplementari seguenti seran efetuadi :',
	'actions_non_traitees' => 'Acioun noun realisadi',
	'actions_realises' => 'Acioun realisadi',
	'afficher_les_plugins_incompatibles' => 'Afichà lu plugin incoumpatible',
	'alerte_compatibilite' => 'Coumpatibilità fourçada',

	// B
	'bouton_activer' => 'Ativà',
	'bouton_actualiser' => 'Atualisà',
	'bouton_actualiser_tout' => 'Atualisà lu depòsiti',
	'bouton_appliquer' => 'Aplicà',
	'bouton_confirmer' => 'Counfirmà',
	'bouton_desactiver' => 'Desativà',
	'bouton_desinstaller' => 'Desinstalà',
	'bouton_installer' => 'Telecargà e ativà',
	'bouton_modifier_depot' => 'Moudificà lou depòsiti',
	'bouton_supprimer' => 'Suprimà',
	'bouton_up' => 'Metre a jou',
	'bulle_actualiser_depot' => 'Atualisà lu paquet dóu depòsiti',
	'bulle_actualiser_tout_depot' => 'Atualisà lu paquet de toui lu depòsiti',
	'bulle_afficher_xml_plugin' => 'Countengut dóu fichié XML dau plugin',
	'bulle_ajouter_spipzone' => 'Ajustà lou depòsiti SPIP-Zone',
	'bulle_aller_demonstration' => 'Anà sus la pàgina de demounstracioun',
	'bulle_aller_depot' => 'Anà sus la pàgina d’aqueu depòsiti',
	'bulle_aller_documentation' => 'Anà sus la pàgina de doucumentacioun',
	'bulle_aller_plugin' => 'Anà sus la pàgina dóu plugin',
	'bulle_supprimer_depot' => 'Suprimà lou depòsiti e lu siéu paquet',
	'bulle_telecharger_archive' => 'Telecargà l’arquivi',
	'bulle_telecharger_fichier_depot' => 'Telecargà lou fichié XML dóu depòsiti',
	'bulle_telecharger_librairie' => 'Telecargà la biblioutéca',

	// C
	'cacher_les_plugins_incompatibles' => 'Escoundre lu plugin incoumpatible',
	'categorie_aucune' => 'Sensa categourìa',
	'categorie_auteur' => 'Autenticacioun, autour, autourousacioun',
	'categorie_communication' => 'Communicacioun, interatività, messagerìa',
	'categorie_date' => 'Agènda, calendari, data',
	'categorie_divers' => 'Ouget nouvèu, servici estèrnou',
	'categorie_edition' => 'Edicioun, estampa, redacioun',
	'categorie_maintenance' => 'Counfiguracioun, mantenença',
	'categorie_multimedia' => 'Image, galerìa, multimedia',
	'categorie_navigation' => 'Navigacioun, recerca, ourganisacioun',
	'categorie_outil' => 'Óutis de desfouloupamen',
	'categorie_performance' => 'Òtimisacioun, proudessa, segurtà',
	'categorie_squelette' => 'Esquèletrou',
	'categorie_statistique' => 'Referençamen, estatìstica',
	'categorie_theme' => 'Tèma',
	'config_activer_log_verbeux' => 'Ativà lu log verbous ?',
	'config_activer_log_verbeux_explication' => 'Aquela oupcioun rende lu log de SVP mai verbous…',
	'config_activer_pas_a_pas' => 'Ativà lou mòdou pas à pas ?',
	'config_activer_pas_a_pas_explication' => 'Ativà aqueu mòdou permet d’afichà un bilan après cada acioun realisada, en plaça d’avé basta un bilan toutal de touti li acioun efetuadi a la fin dei tratamen.',
	'config_activer_runtime' => 'Ativà lou mòdou runtime ?',
	'config_activer_runtime_explication' => 'Lou mòdou runtime (ahì) carga que lu plugin coumpatible embé la versioun courrenta dóu vouòstre SPIP, cen qu’es fouòrça counseiat per la majourença dei usança. En mòdou noun runtime (noun), toui lu plugin d’un depòsiti soun cargat, quauque sìgue la versioun dóu SPIP en cours. Acò es basta utile quoura si utilisà SVP per presentà toui lu plugin esistant couma es fach per lou sit Plugins SPIP (plugins.spip.net)',
	'config_autoriser_activer_paquets_obsoletes' => 'Autourisà l’ativacioun dei paquet oussoulet ?',
	'config_autoriser_activer_paquets_obsoletes_explication' => 'Lu paquet oussoulet soun dei paquet loucal present que soun mai viei que d’autre paquet loucal. L’oussoulecència es estabilida soubre la basa de l’estat (stable, test, dev) dóu paquet e finda soubre la basa de la siéu versioun. Ativàs aquela oupcioun s’auguràs maugrà tout d’avé la poussibilità d’ativà aquelu plugin oussoulet.',
	'config_depot_editable' => 'Permetre l’edicioun dei depòsiti ?',
	'config_depot_editable_explication' => 'Acò rende li infourmacioun d’un depòsiti editable e permet eventualamen de jougne dei mot clau o dei doucumen. Aquela oupcioun deurìa interessà degun ! Vourguès laissà « noun » !',
	'confirmer_desinstaller' => 'Mèfi, la desinstalacioun d’un plugin <b>escassa</b> li siéu dounada de la basa e es irreversibla.<br />Se noun sias certen, desativàs simplamen lou plugin.',
	'confirmer_telecharger_dans' => 'Lou plugin serà cargat en un repertori (@dir@) qu’esista jà.
	Acò esquisserà lou countengut d’aqueu repertori.
	Una còpia dóu viei countengut serà sauvagardada en « @dir_backup@ ».
		Devès counfirmà aquela acioun.',

	// E
	'erreur_actions_non_traitees' => 'D’uni acioun noun soun realisadi. Magara que vengue d’un errour dóu tems dei acioun da realisà, o d’un afichage d’aquela pàgina aloura qu’aqueli acioun noun soun encara acabadi. Li acioun èron estat lançadi per @auteur@ lou @date@.',
	'erreur_auth_plugins_ajouter_lib' => 'Noun avès lu drech necessari per ajustà una biblioutèca.',
	'erreur_dir_dib_ecriture' => 'Lou repertori dei biblioutèca @dir@ noun es achessible en escritura. Empoussible de lì cargà una biblioutèca !',
	'erreur_dir_dib_indefini' => 'Lou repertori _DIR_LIB noun es definit. Empoussible de lì cargà una biblioutèca !',
	'erreur_dir_plugins_auto' => 'Lou repertori « plugins/auto » que permet de telecargà dei paquet 
		noun es creà o noun es achessible en escritura.
		<strong>Lou devès creà per poudé instalà de nouvèu plugin despì aquela interfaça.</strong>',
	'erreur_dir_plugins_auto_ecriture' => 'Lou repertori dei paquet @dir@ noun es achessible en escritura. Empoussible de lì cargà un paquet !',
	'erreur_dir_plugins_auto_indefini' => 'Lou repertori _DIR_PLUGIN_AUTO noun es definit. Empoussible de lì cargà un paquet !',
	'erreur_dir_plugins_auto_titre' => '« plugins/auto » es inachessible !',
	'erreur_teleporter_chargement_source_impossible' => 'Empoussible de cargà lou sourgent @source@',
	'erreur_teleporter_destination_erreur' => 'Repertori @dir@ noun achessible da telepourtà',
	'erreur_teleporter_echec_deballage_archive' => 'Empoussible d’estraire @fichier@',
	'erreur_teleporter_format_archive_non_supporte' => 'Lou fourmat @extension@ noun es supourtat dau telepourtatour',
	'erreur_teleporter_methode_inconue' => 'Mètodou @methode@ escounouissut da telepourtà',
	'erreur_teleporter_type_fichier_inconnu' => 'Tìpou de fichié escounouissut per lou sourgent @source@',
	'erreurs_xml' => 'Empoussible de legì certeni descricioun XML',
	'explication_destination' => 'Lou camin serà carculat dau noum de l’arquivi se noun  l’aclafissès.',

	// F
	'fieldset_debug' => 'Debug',
	'fieldset_edition' => 'Edicioun',
	'fieldset_fonctionnement' => 'Founciounamen',

	// I
	'info_1_depot' => '1 depòsiti',
	'info_1_paquet' => '1 paquet',
	'info_1_plugin' => '1 plugin',
	'info_admin_plugin_actif_non_verrou_non' => 'Aquela pàgina lista lu plugin noun atiéu dóu sit. Aquelu plugin soun sempre noun ferouià.',
	'info_admin_plugin_actif_non_verrou_tous' => 'Aquela pàgina lista lu plugin noun atiéu dóu sit. Aquelu plugin soun sempre noun ferouià.',
	'info_admin_plugin_actif_oui_verrou_non' => 'Aquela pàgina lista lu plugin atiéu e noun ferouiat dóu sit.',
	'info_admin_plugin_actif_oui_verrou_tous' => 'Aquela pàgina lista toui lu plugin atiéu dóu sit, ferouiat o noun.',
	'info_admin_plugin_verrou_non' => 'Aquela pàgina lista toui lu plugin noun ferouiat dóu sit, atiéu o noun.',
	'info_admin_plugin_verrou_tous' => 'Aquela pàgina lista toui lu plugin dóu sit.',
	'info_admin_plugin_verrouille' => 'Aquela pàgina lista lu plugin atiéu e ferouiat (situat en lou repertori <code>@dir_plugins_dist@</code>).
	Se lu auguràs desativà, vourguès countatà lou webmestre dóu sit,
	o vi repourtà <a href="http://programmer.spip.net/repertoire_plugins-dist">a la doucumentacioun</a>.',
	'info_adresse_spipzone' => 'SPIP-Zone - Plugin',
	'info_ajouter_depot' => 'En ajustant dei depòsiti a vouòstra basa, aurès la poussibilità d’outenì dei infourmacioun e d’efetuà dei recerca soubre toui lu paquet oustelat dai depòsiti ajustat.<br />Un depòsiti es descrich da un fichié XML countenent li infourmacioun soubre lu depòsiti e soubre toui lu siéu paquet.',
	'info_aucun_depot' => 'mìnga depòsiti',
	'info_aucun_depot_ajoute' => 'Mìnga depòsiti dispounible !<br /> Utilisàs lou fourmulari aquì souta da ajustà lou depòsiti « SPIP-Zone - Plugins » que l’url es jà preclafida o un autre depòsiti de la vouòstra chausida.',
	'info_aucun_paquet' => 'mìnga paquet',
	'info_aucun_plugin' => 'mìnga plugin',
	'info_boite_charger_plugin' => '<strong>Aquela pàgina es basta achessible ai webmestre dóu sit.</strong><p>Vi permete de recercà dei plugin mes da dispousicioun dai depòsiti registrat en la vouòstra counfiguracioun e lu instalà fisicamen sus lou vouòstre servidou</p>',
	'info_boite_depot_gerer' => '<strong>Aquela pàgina es basta achessible ai webmestre dóu sit.</strong><p>Permet l’ajountamen et l’atualisacioun dei depòsiti de plugin.</p>',
	'info_charger_plugin' => 'Per ajustà un plugin o mai, efetuàs en premié una recerca multicriteri sus lu plugin de la galassìa SPIP. La recerca enclude basta lu plugin coumpatible embé la versioun SPIP instalada e signala lu plugin jà atiéu sus lou sit.',
	'info_compatibilite_dependance' => 'Per @compatibilite@ :',
	'info_contributions_hebergees' => '@total_autres@ autri countribucioun ousteladi',
	'info_critere_phrase' => 'Sesissès lu mot clau da cercà en lou prefis, lou noum, l’eslougan, la descricioun e lu autour dei plugin',
	'info_depots_disponibles' => '@total_depots@ depòsiti',
	'info_fichier_depot' => 'Sesissès l’url dóu fichié de descricioun dau depòsiti da ajustà.<br />Per ajustà lou depòsiti « SPIP-Zone - Plugins » clicàs soubre aquel estac : ',
	'info_nb_depots' => '@nb@ depòsiti',
	'info_nb_paquets' => '@nb@ paquet',
	'info_nb_plugins' => '@nb@ plugin',
	'info_paquets_disponibles' => '@total_paquets@ paquet dispounible',
	'info_plugin_attente_dependance' => 'dependença manquanti',
	'info_plugin_incompatible' => 'versioun incoumpatible',
	'info_plugin_installe' => 'ja instalat',
	'info_plugin_obsolete' => 'versioun perimada',
	'info_plugins_disponibles' => '@total_plugins@ plugin dispounible',
	'info_plugins_heberges' => '@total_plugins@ plugin oustelat',
	'info_tri_nom' => 'classificat da ordre alfabéticou',
	'info_tri_score' => 'classificat da pertinença descreissenta',
	'info_type_depot_git' => 'Depòsiti gerat souta GIT',
	'info_type_depot_manuel' => 'Depòsiti gerat manualamen',
	'info_type_depot_svn' => 'Depòsiti gerat souta SVN',
	'info_verrouille' => 'Empoussible de desativà o de desinstalà aqueu plugin.',
	'installation_en_cours' => 'Lu acioun demandadi soun en cours de tratamen',

	// L
	'label_1_autre_contribution' => 'autra countributioun',
	'label_actualise_le' => 'Atualisat lou',
	'label_archive' => 'URL da l’arquivi',
	'label_branches_spip' => 'Coumpatible',
	'label_categorie' => 'Categourìa',
	'label_compatibilite_spip' => 'Coumpatibilità',
	'label_critere_categorie' => 'Categourìa',
	'label_critere_depot' => 'Depòsiti',
	'label_critere_doublon' => 'Coumpatibilità',
	'label_critere_etat' => 'Estat',
	'label_critere_phrase' => 'Recercà en lu plugin',
	'label_destination' => 'Camin despì lou repertori  « auto » doun depousà lou plugin',
	'label_modifie_le' => 'Moudificat lou',
	'label_n_autres_contributions' => 'autri countribucioun',
	'label_prefixe' => 'Prefis',
	'label_selectionner_plugin' => 'Seleciounà aqueu plugin',
	'label_tags' => 'Tag',
	'label_type_depot' => 'Tìpou de depòsiti :',
	'label_type_depot_git' => 'Depòsiti souta GIT',
	'label_type_depot_manuel' => 'Depòsiti manual',
	'label_type_depot_svn' => 'Depòsiti souta SVN',
	'label_url_archives' => 'URL dóu countengut dei arquivi',
	'label_url_brouteur' => 'URL de la raïs dei sourgent',
	'label_url_serveur' => 'URL dóu servidou',
	'label_version' => 'Versioun',
	'label_xml_depot' => 'Fichié XML dóu depòsiti',
	'label_xml_plugin' => 'XML',
	'legende_installer_plugins' => 'Instalà dei plugin',
	'legende_rechercher_plugins' => 'Recercà dei plugin',
	'lien_demo' => 'Demounstracioun',
	'lien_documentation' => 'Doucumentacioun',

	// M
	'message_action_finale_get_fail' => 'Lou plugin « @plugin@ » (versioun : @version@) noun es estat recuperat courretamen',
	'message_action_finale_get_ok' => 'Lou plugin « @plugin@ » (versioun : @version@) es estat recuperat courretamen',
	'message_action_finale_getlib_fail' => 'L’instalacioun de la biblioutéca « @plugin@ » a souhit',
	'message_action_finale_getlib_ok' => 'La biblioutéca « @plugin@ » es estada instalada',
	'message_action_finale_geton_fail' => 'Lou telecargamen o l’ativacioun dóu plugin « @plugin@ » (versioun : @version@) noun si soun efetuat courretamen',
	'message_action_finale_geton_ok' => 'Lou telecargamen e l’ativacioun dóu plugin « @plugin@ » (versioun : @version@) si soun efetuat courretamen',
	'message_action_finale_install_fail' => 'L’instalacioun dóu plugin « @plugin@ » (versioun : @version@) a souhit',
	'message_action_finale_install_ok' => 'L’instalacioun dóu plugin « @plugin@ » (versioun : @version@) s’es efetuada courretamen',
	'message_action_finale_kill_fail' => 'Lu fichié dóu plugin « @plugin@ » (versioun : @version@) noun soun estat escassat courretamen',
	'message_action_finale_kill_ok' => 'Lu fichié dóu plugin « @plugin@ » (versioun : @version@) soun estat escassat courretamen',
	'message_action_finale_off_fail' => 'La desativacioun dóu plugin « @plugin@ » (versioun : @version@) noun s’es efetuada courretamen',
	'message_action_finale_off_ok' => 'La desativacioun dóu plugin « @plugin@ » (versioun : @version@) s’es efetuada courretamen',
	'message_action_finale_on_fail' => 'L’ativacioun dóu plugin « @plugin@ » (versioun : @version@) noun s’es efetuada courretamen',
	'message_action_finale_on_ok' => 'L’ativacioun dóu plugin « @plugin@ » (versioun : @version@) s’es efetuada courretamen',
	'message_action_finale_stop_fail' => 'La desinstalacioun dóu plugin « @plugin@ » (versioun : @version@) noun s’es efetuada courretamen',
	'message_action_finale_stop_ok' => 'La desinstalacioun dóu plugin « @plugin@ » (versioun : @version@) s’es efetuada courretamen',
	'message_action_finale_up_fail' => 'La messa a jou dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) noun s’es efetuada courretamen',
	'message_action_finale_up_ok' => 'La messa a jou dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) s’es efetuada courretamen',
	'message_action_finale_upon_fail' => 'La messa a jou e l’ativacioun dóu plugin « @plugin@ » (da la versioun : @version@ a @version_maj@) noun si soun efetuadi courretamen',
	'message_action_finale_upon_ok' => 'La messa a jou e l’ativacioun dóu plugin « @plugin@ » (de la versioun : @version@ a @version_maj@) si soun efetuadi courretamen',
	'message_action_get' => 'Telecargà lou plugin « @plugin@ » (versioun : @version@)',
	'message_action_getlib' => 'Telecargà la biblioutéca « <a href="@version@" class="spip_out">@plugin@</a> »',
	'message_action_geton' => 'Telecargà a ativà lou plugin « @plugin@ » (versioun : @version@)',
	'message_action_install' => 'Lou plugin « @plugin@ » (versioun : @version@) va estre instalat',
	'message_action_kill' => 'Supressioun dei fichié dóu plugin « @plugin@ » (versioun : @version@)',
	'message_action_off' => 'Desativà lou plugin « @plugin@ » versioun : @version@)',
	'message_action_on' => 'Ativà lou plugin « @plugin@ » (versioun : @version@)',
	'message_action_stop' => 'Desinstalà lou plugin « @plugin@ » (versioun : @version@)',
	'message_action_up' => 'Messa a jou dóu plugin « @plugin@ » (da la versioun @version@ a @version_maj@)',
	'message_action_upon' => 'Messa a jou e ativacioun dóu plugin « @plugin@ » (versioun : @version@)',
	'message_dependance_plugin' => 'Lou plugin @plugin@ depende da @dependance@.',
	'message_dependance_plugin_version' => 'Lou plugin @plugin@ depende da @dependance@ @version@',
	'message_erreur_aucun_plugin_selectionne' => 'Mìnga plugin seleciounat.',
	'message_erreur_ecriture_lib' => '@plugin@ a da besoun de la biblioutèca <a href="@lib_url@">@lib@</a> situada en lou repertori <var>lib/</var> en la raïs dóu vouòstre sit. Pùra, aqueu repertori noun esista o noun es achessible en escritura. Devès instalà manualamen aquela biblioutèca o creà aqueu repertori en lì dounant dei permissioun d’escritura.',
	'message_erreur_maj_inconnu' => 'Messa a jou impoussibla d’un plugin escounouissut.',
	'message_erreur_plugin_introuvable' => 'Es empoussible de trouvà lou plugin @plugin@ per @action@.',
	'message_erreur_plugin_non_actif' => 'Es empoussible de desativà un plugin noun atiéu.',
	'message_incompatibilite_spip' => '@plugin@ noun es coumpatible embé la versioun de SPIP qu’utilisàs.',
	'message_nok_aucun_depot_disponible' => 'Mìnga plugin es dispounible ! Vourguès anà sus la pàgina de gestioun dei depòsiti da ajustà dei lista de plugin.',
	'message_nok_aucun_paquet_ajoute' => 'Lou depòsiti « @url@ » founisse mìnga paquet nouvèu a raport a la basa jà registrada. Noun es pi estat ajustat',
	'message_nok_aucun_plugin_selectionne' => 'Mìnga plugin da instalà. Vourguès selecioun) lu plugin da instalà',
	'message_nok_champ_obligatoire' => 'Aqueu camp es oubligatori',
	'message_nok_depot_deja_ajoute' => 'L’adressa « @url@ » courrespouònde a un depòsiti jà ajustat',
	'message_nok_maj_introuvable' => 'Messa a jou dóu plugin @plugin@ introuvable.',
	'message_nok_plugin_inexistant' => 'Lou plugin demandat noun esista (@plugin@).',
	'message_nok_sql_insert_depot' => 'Errour SQL dóu tems de l’ajountamen dóu depòsiti @objet@',
	'message_nok_url_archive' => 'L’URL de l’arquivi es invalide',
	'message_nok_url_depot_incorrecte' => 'L’adressa « @url@ » es mau couret',
	'message_nok_xml_non_conforme' => 'Lou fichié XML « @fichier@ » de descricioun dóu depòsiti noun es counforme',
	'message_nok_xml_non_recupere' => 'Lou fichié XML « @fichier@ » a pas pouscut estre recuperat',
	'message_ok_aucun_plugin_trouve' => 'Mìnga plugin courrespouònde ai critèri chausit.',
	'message_ok_depot_ajoute' => 'Lou depòsiti « @url@ » es estat ajustat.',
	'message_ok_plugins_trouves' => '@nb_plugins@ plugin courrespouòndon ai critèri chausit (@tri@). Seleciounàs aquì souta lu plugin que auguràs de telecargà e ativà soubre lou vouòstre servidou.',
	'message_telechargement_archive_effectue' => 'L’arquivi es estada courretamen estracha en @dir@.',

	// N
	'nettoyer_actions' => 'Netejà aqueli acioun ! Acò escasserà la lista dei acioun que reston da tratà.',

	// O
	'onglet_depots' => 'Gerà lu depòsiti',
	'option_categorie_toute' => 'Touti li categourìa',
	'option_depot_tout' => 'Toui lu depòsiti',
	'option_doublon_non' => 'La darrièra versioun',
	'option_doublon_oui' => 'Touti li versioun coumpatibli',
	'option_etat_tout' => 'Toui lu estat',

	// P
	'placeholder_phrase' => 'prefis, noum, eslougan, descritiéu o autour',
	'plugin_info_actif' => 'Plugin atiéu',
	'plugin_info_up' => 'Una messa a jou dóu plugin es dispounible (versioun @version@)',
	'plugin_info_verrouille' => 'Plugin ferouiat',
	'plugins_inactifs_liste' => 'Inatiéu',
	'plugins_non_verrouilles_liste' => 'Noun ferouiat',
	'plugins_verrouilles_liste' => 'Ferouiat',

	// R
	'resume_table_depots' => 'Lista dei depòsiti ajustat',
	'resume_table_paquets' => 'Lista dei paquet',
	'resume_table_plugins' => 'Lista dei plugin @categorie@',

	// T
	'telecharger_archive_plugin_explication' => 'Poudès telecargà un arquivi que si cargerà
		en lou vouòstre repertori « plugins/auto », en escrivent l’URL de l’arquivi en lou camp de sesìda.',
	'titre_depot' => 'Depòsiti',
	'titre_depots' => 'Depòsiti',
	'titre_form_ajouter_depot' => 'Ajustà un depòsiti',
	'titre_form_charger_plugin' => 'Recercà e ajustà dei plugin',
	'titre_form_charger_plugin_archive' => 'Telecargà un plugin da la siéu arquivi',
	'titre_form_configurer_svp' => 'Counfigurà lou Servidou de Plugins',
	'titre_liste_autres_contributions' => 'Esquèletrou, biblioutèca, juec d’icona...',
	'titre_liste_autres_depots' => 'Autre depòsiti',
	'titre_liste_depots' => 'Lista dei depòsiti dispounible',
	'titre_liste_paquets_plugin' => 'Lista dei paquet dóu plugin',
	'titre_liste_plugins' => 'Lista dei plugin',
	'titre_logo_depot' => 'Logou dóu depòsiti',
	'titre_logo_plugin' => 'Logou dóu plugin',
	'titre_nouveau_depot' => 'Depòsiti nouvèu',
	'titre_page_configurer' => 'Servidou de Plugin',
	'titre_paquet' => 'Paquet',
	'titre_paquets' => 'Paquet',
	'titre_plugin' => 'Plugin',
	'titre_plugins' => 'Plugin',
	'tout_cocher' => 'Entacà tout',
	'tout_cocher_up' => 'Entacà li metudi a jou',
	'tout_decocher' => 'Destacà tout'
);

?>
